@@ -12,13 +12,15 @@ from django.utils.translation import ugettext_lazy as _
 color_re = re.compile('^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$')
 validate_color = RegexValidator(color_re, _(u'Enter a valid color.'), 'invalid')
 
+
 class ColorWidget(forms.Widget):
     class Media:
-        js = [settings.MEDIA_URL + 'colorfield/jscolor.js']
+        js = [settings.STATIC_URL + 'colorfield/jscolor/jscolor.js']
         
     def render(self, name, value, attrs=None):
         return render_to_string('colorfield/color.html', locals())
-        
+
+
 class ColorField(models.CharField):
     default_validators = [validate_color]
 
@@ -30,4 +32,10 @@ class ColorField(models.CharField):
         kwargs['widget'] = ColorWidget
         return super(ColorField, self).formfield(**kwargs)
 
+try:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^colorfield\.fields\.ColorField"])
+except ImportError:
+    pass
+
 # vim: et sw=4 sts=4
